@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2017, Ilya Kotov <forkotov02@hotmail.ru>
+ * Copyright (c) 2014-2017, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -43,12 +43,17 @@
 #endif
 #include <QFile>
 #include <QFileSystemWatcher>
+
+#include <qt5ct/qt5ct.h>
+#include "qt5ctplatformtheme.h"
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)) && !defined(QT_NO_DBUS)
+#include <private/qdbusmenubar_p.h>
+#endif
 #if !defined(QT_NO_DBUS) && !defined(QT_NO_SYSTEMTRAYICON)
 #include <private/qdbustrayicon_p.h>
 #endif
 
-#include <qt5ct/qt5ct.h>
-#include "qt5ctplatformtheme.h"
+
 
 Q_LOGGING_CATEGORY(lqt5ct, "qt5ct")
 
@@ -56,13 +61,6 @@ Q_LOGGING_CATEGORY(lqt5ct, "qt5ct")
 
 Qt5CTPlatformTheme::Qt5CTPlatformTheme()
 {
-    m_customPalette = 0;
-    m_update = false;
-    m_usePalette = true;
-#if !defined(QT_NO_DBUS) && !defined(QT_NO_SYSTEMTRAYICON)
-    m_dbusTrayAvailable = false;
-    m_checkDBusTray = true;
-#endif
     if(QGuiApplication::desktopSettingsAware())
     {
         readSettings();
@@ -85,6 +83,20 @@ Qt5CTPlatformTheme::~Qt5CTPlatformTheme()
         delete m_customPalette;
 }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)) && !defined(QT_NO_DBUS)
+QPlatformMenuBar *Qt5CTPlatformTheme::createPlatformMenuBar() const
+{
+    if(m_checkDBusGlobalMenu)
+    {
+        QDBusConnection conn = QDBusConnection::sessionBus();
+        m_dbusGlobalMenuAvailable = conn.interface()->isServiceRegistered("com.canonical.AppMenu.Registrar");
+        m_checkDBusGlobalMenu = false;
+        qCDebug(lqt5ct) << "D-Bus global menu:" << (m_dbusGlobalMenuAvailable ? "yes" : "no");
+    }
+    return (m_dbusGlobalMenuAvailable ? new QDBusMenuBar() : nullptr);
+}
+#endif
+
 #if !defined(QT_NO_DBUS) && !defined(QT_NO_SYSTEMTRAYICON)
 QPlatformSystemTrayIcon *Qt5CTPlatformTheme::createPlatformSystemTrayIcon() const
 {
@@ -95,14 +107,14 @@ QPlatformSystemTrayIcon *Qt5CTPlatformTheme::createPlatformSystemTrayIcon() cons
         m_checkDBusTray = false;
         qCDebug(lqt5ct) << "D-Bus system tray:" << (m_dbusTrayAvailable ? "yes" : "no");
     }
-    return (m_dbusTrayAvailable ? new QDBusTrayIcon() : 0);
+    return (m_dbusTrayAvailable ? new QDBusTrayIcon() : nullptr);
 }
 #endif
 
 const QPalette *Qt5CTPlatformTheme::palette(QPlatformTheme::Palette type) const
 {
     Q_UNUSED(type);
-    return (m_usePalette ? m_customPalette : 0);
+    return (m_usePalette ? m_customPalette : nullptr);
 }
 
 const QFont *Qt5CTPlatformTheme::font(QPlatformTheme::Font type) const
@@ -120,6 +132,8 @@ QVariant Qt5CTPlatformTheme::themeHint(QPlatformTheme::ThemeHint hint) const
         return m_cursorFlashTime;
     case MouseDoubleClickInterval:
         return m_doubleClickInterval;
+    case QPlatformTheme::ToolButtonStyle:
+        return m_toolButtonStyle;
     case QPlatformTheme::SystemIconThemeName:
         return m_iconTheme;
     case QPlatformTheme::StyleNames:
@@ -130,6 +144,10 @@ QVariant Qt5CTPlatformTheme::themeHint(QPlatformTheme::ThemeHint hint) const
         return m_buttonBoxLayout;
     case QPlatformTheme::UiEffects:
         return m_uiEffects;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
+    case QPlatformTheme::WheelScrollLines:
+        return m_wheelScrollLines;
+#endif
     default:
         return QPlatformTheme::themeHint(hint);
     }
@@ -140,6 +158,7 @@ void Qt5CTPlatformTheme::applySettings()
     if(!QGuiApplication::desktopSettingsAware())
         return;
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 5, 0))
     if(!m_update)
     {
         //do not override application palette
@@ -149,15 +168,25 @@ void Qt5CTPlatformTheme::applySettings()
             qCDebug(lqt5ct) << "palette support is disabled";
         }
     }
+#endif
 
 #ifdef QT_WIDGETS_LIB
     if(hasWidgets())
     {
         qApp->setFont(m_generalFont);
 
+        //Qt 5.6 or higher should be use themeHint function on application startup.
+        //So, there is no need to call this function first time.
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
+        if(m_update)
+            qApp->setWheelScrollLines(m_wheelScrollLines);
+#else
+        qApp->setWheelScrollLines(m_wheelScrollLines);
+#endif
+
         if(m_update && qApp->style()->objectName() == "qt5ct-style") //ignore application style
             qApp->setStyle("qt5ct-style"); //recreate style object
-            
+
         if(m_update && m_usePalette)
         {
             if(m_customPalette)
@@ -248,6 +277,8 @@ void Qt5CTPlatformTheme::readSettings()
     m_buttonBoxLayout = QPlatformTheme::themeHint(QPlatformTheme::DialogButtonBoxLayout).toInt();
     m_buttonBoxLayout = settings.value("buttonbox_layout", m_buttonBoxLayout).toInt();
     QCoreApplication::setAttribute(Qt::AA_DontShowIconsInMenus, !settings.value("menus_have_icons", true).toBool());
+    m_toolButtonStyle = settings.value("toolbutton_style", Qt::ToolButtonFollowStyle).toInt();
+    m_wheelScrollLines = settings.value("wheel_scroll_lines", 3).toInt();
 
     //load effects
     m_uiEffects = QPlatformTheme::themeHint(QPlatformTheme::UiEffects).toInt();
@@ -282,7 +313,7 @@ void Qt5CTPlatformTheme::readSettings()
 #ifdef QT_WIDGETS_LIB
 bool Qt5CTPlatformTheme::hasWidgets()
 {
-    return qobject_cast<QApplication *> (qApp) != 0;
+    return qobject_cast<QApplication *> (qApp) != nullptr;
 }
 #endif
 
