@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2017, Ilya Kotov <forkotov02@hotmail.ru>
+ * Copyright (c) 2014-2017, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -35,8 +35,20 @@
 #include <QPalette>
 #include <QLoggingCategory>
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 5, 0))
+#ifndef QT_NO_SYSTEMTRAYICON
+#define QT_NO_SYSTEMTRAYICON
+#endif
+#endif
+
 class QPalette;
+#if !defined(QT_NO_DBUS) && !defined(QT_NO_SYSTEMTRAYICON)
 class QPlatformSystemTrayIcon;
+#endif
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)) && !defined(QT_NO_DBUS)
+class QPlatformMenuBar;
+#endif
 
 class Qt5CTPlatformTheme : public QObject, public QPlatformTheme
 {
@@ -49,7 +61,9 @@ public:
 
     //virtual QPlatformMenuItem* createPlatformMenuItem() const;
     //virtual QPlatformMenu* createPlatformMenu() const;
-    //virtual QPlatformMenuBar* createPlatformMenuBar() const;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)) && !defined(QT_NO_DBUS)
+    virtual QPlatformMenuBar* createPlatformMenuBar() const;
+#endif
     //virtual void showPlatformMenuBar() {}
     //virtual bool usePlatformNativeDialog(DialogType type) const;
     //virtual QPlatformDialogHelper *createPlatformDialogHelper(DialogType type) const;
@@ -82,17 +96,23 @@ private:
     QString loadStyleSheets(const QStringList &paths);
     QPalette loadColorScheme(const QString &filePath);
     QString m_style, m_iconTheme, m_userStyleSheet, m_prevStyleSheet;
-    QPalette *m_customPalette;
+    QPalette *m_customPalette = nullptr;
     QFont m_generalFont, m_fixedFont;
     int m_doubleClickInterval;
     int m_cursorFlashTime;
     int m_uiEffects;
     int m_buttonBoxLayout;
-    bool m_update;
-    bool m_usePalette;
+    bool m_update = false;
+    bool m_usePalette = true;
+    int m_toolButtonStyle = Qt::ToolButtonFollowStyle;
+    int m_wheelScrollLines = 3;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)) && !defined(QT_NO_DBUS)
+    mutable bool m_dbusGlobalMenuAvailable = false;
+    mutable bool m_checkDBusGlobalMenu = true;
+#endif
 #if !defined(QT_NO_DBUS) && !defined(QT_NO_SYSTEMTRAYICON)
-    mutable bool m_dbusTrayAvailable;
-    mutable bool m_checkDBusTray;
+    mutable bool m_dbusTrayAvailable = false;
+    mutable bool m_checkDBusTray = true;
 #endif
 
 };
