@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2017, Ilya Kotov <forkotov02@hotmail.ru>
+ * Copyright (c) 2014-2017, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -44,8 +44,6 @@ AppearancePage::AppearancePage(QWidget *parent) :
     TabPage(parent),
     m_ui(new Ui::AppearancePage)
 {
-    m_selectedStyle = 0;
-
     m_ui->setupUi(this);
     QStringList keys = QStyleFactory::keys();
     keys.removeAll("qt5ct-style"); //hide qt5ct proxy style
@@ -312,7 +310,7 @@ void AppearancePage::readSettings()
 
     QDir("/").mkpath(Qt5CT::userColorSchemePath());
     findColorSchemes(Qt5CT::userColorSchemePath());
-    findColorSchemes(Qt5CT::sharedColorSchemePath());
+    findColorSchemes(Qt5CT::sharedColorSchemePaths());
 
     if(m_ui->colorSchemeComboBox->count() == 0)
     {
@@ -367,6 +365,12 @@ void AppearancePage::findColorSchemes(const QString &path)
     }
 }
 
+void AppearancePage::findColorSchemes(const QStringList &paths)
+{
+    foreach (QString p, paths)
+        findColorSchemes(p);
+}
+
 QPalette AppearancePage::loadColorScheme(const QString &filePath)
 {
     QPalette customPalette;
